@@ -13,6 +13,7 @@ class Vendor(Enum):
     aws = 1
     google = 2
     cloudflare = 3
+    digitalocean = 4
 
 
 # @TODO: Can't use this, because python3.7 compatibility.
@@ -43,6 +44,7 @@ class IdentificationTool:
             "aws": self.iter_aws,
             "google": self.iter_google,
             "cloudflare": self.iter_cloudflare,
+            "digitalocean": self.iter_digitalocean,
         }
         self.ips = []
         if self.EXPORT_FP.exists() and (self.EXPORT_FP / "packed.bin").exists():
@@ -101,6 +103,17 @@ class IdentificationTool:
         for value in data.split("\n"):
             yield value
 
+    def iter_digitalocean(self):
+        data = ""
+
+        with open(self.RANGES_FP / "digitalocean.csv") as f:
+            data += f.read()
+
+        for row in data.split("\n"):
+            value, *_ = row.split(",")
+            value = value.strip(" \n\r\t")
+            if value:
+                yield value
 
     def iterate_raw_nets(self):
         unique = set()
